#!/bin/bash
# Automate multilanguage CentOS slide PNG image rendering.
#
# Alain Reguera Delgado <alain.reguera@gmail.com>
# http://wiki.centos.org/ArtWork/DistroDesign/AutomateSlideRendering


LANGUAGE=$1

# Define translation directory
if [ $LANGUAGE ];then
	DIRECTORY=`ls TXT/ | grep $LANGUAGE`;
else
	DIRECTORY=`ls TXT/`
fi

# Check directories existance.
for i in `echo "PNG SVG TXT"`; do
if [ ! -d $i ]; then
	echo "Directory $i is missing.";
	exit;
fi
done;

# Clean up PNG directory.
#if [ "`ls PNG/`" != "" ];then
#	echo 'Cleaning up PNG directory ...';
#	cd PNG/
#	rm -r *;
#	cd ..
#fi

# Translate slides
for i in $DIRECTORY; do

	# Only if file is a directory
	if [ -d TXT/$i ];then

	# Create PNG directory (language related)
	if [ ! -d PNG/$i ];then
		mkdir PNG/$i;
	fi

	# Recover translation file name path.
	for j in `ls TXT/$i | grep '\.sed'`; do
		SLIDETXT=TXT/$i/$j;
		SLIDEPNG=`echo "PNG/$i/$j" | sed -e 's/sed/png/;'`;
		SLIDESVG=`echo "SVG/$j" | sed -e 's/sed/svg/'`;

		if [ -a $SLIDESVG ];then
			# Use svg template file to create a translated temporal one,
			# used to build the related png file. 
			sed -f $SLIDETXT $SLIDESVG > tmp-`basename $SLIDESVG`;

			# Use inkscape program to create a png file from recently
			# created svg temporal file.
			inkscape tmp-`basename $SLIDESVG` --export-id=gANACONDASLIDE --export-png=$SLIDEPNG;

			# Remove temporal svg file.
			rm tmp-`basename $SLIDESVG`;
		else
			echo '--------------------'
			echo "ATTENTION! $SLIDEPNG file was not created.";
			echo "           $SLIDESVG file cannot be found.";
			echo '--------------------'

		fi

	done

	fi
done
